@@ -21,14 +21,7 @@ pub enum Error {
 	#[error("failed to parse float")]
 	ParseFloat(#[from] std::num::ParseFloatError),
 	#[cfg(feature = "require-parse-names")]
-	#[error("failed to parse torrent name: `{0}`")]
-	ParseTorrentName(String)
-}
-
-#[cfg(feature = "require-parse-names")]
-impl Error {
-	pub fn parse_name_failure(name: &str) -> Self {
-		Self::ParseTorrentName(name.to_string())
-	}
+	#[error("failed to parse torrent name")]
+	ParseTorrentName(#[from] torrent_name_parser::error::ErrorMatch)
 }
 
