@@ -4,8 +4,6 @@ extern crate rss;
 extern crate thiserror;
 extern crate urlencoding;
 
-use std::convert::TryFrom;
-
 use bytes::Buf;
 use bytes::Bytes;
 use itertools::Itertools;
@@ -18,11 +16,14 @@ use tracing::instrument;
 mod error;
 pub use error::Error;
 mod torrent;
-pub use torrent::Torrent;
+
 #[cfg(any(feature = "parse-names", feature = "require-parse-names"))]
 /// Re-exported from [`torrent-name-parser`](torrent_name_parser::Metadata)
 pub use torrent_name_parser::Metadata;
 
+/// Re-exported from [`torrent-common`](torrent_common::Torrent)
+pub use torrent_common::Torrent;
+
 #[derive(Clone)]
 pub struct Client {
 	http: reqwest::Client,
@@ -87,7 +88,7 @@ impl Client {
 			qparams.push(("ep", SmartCow::Owned(String::from(v.to_string()))))
 		}
 		let items = self.get_items("tvsearch", qparams).await?;
-		Ok(items.into_iter().map(Torrent::try_from).collect::<Vec<_>>())
+		Ok(items.into_iter().map(torrent::from_item).collect::<Vec<_>>())
 	}
 
 	#[instrument(err, level = "info", skip(self))]
@@ -100,7 +101,7 @@ impl Client {
 			qparams.push(("imdbid", SmartCow::Owned(String::from(v.to_string()))))
 		}
 		let items = self.get_items("movies", qparams).await?;
-		Ok(items.into_iter().map(Torrent::try_from).collect::<Vec<_>>())
+		Ok(items.into_iter().map(torrent::from_item).collect::<Vec<_>>())
 	}
 }
 
@@ -391,7 +392,7 @@ mod tests {
 		let items = channel.into_items();
 		assert!(items.len() == 11);
 		for item in items.into_iter() {
-			Torrent::try_from(item).unwrap();
+			torrent::from_item(item).unwrap();
 		}
 	}
 }
